@@ -6,8 +6,25 @@ import (
 	"fmt"
 
 	"github.com/getkin/kin-openapi/jsoninfo"
+	"github.com/go-openapi/jsonpointer"
 )
 
+type Links map[string]*LinkRef
+
+func (l Links) JSONLookup(token string) (interface{}, error) {
+	ref, ok := l[token]
+	if ok == false {
+		return nil, fmt.Errorf("object has no field %q", token)
+	}
+
+	if ref != nil && ref.Ref != "" {
+		return &Ref{Ref: ref.Ref}, nil
+	}
+	return ref.Value, nil
+}
+
+var _ jsonpointer.JSONPointable = (*Links)(nil)
+
 // Link is specified by OpenAPI/Swagger standard version 3.0.
 type Link struct {
 	ExtensionProps
@@ -27,12 +44,12 @@ func (value *Link) UnmarshalJSON(data []byte) error {
 	return jsoninfo.UnmarshalStrictStruct(data, value)
 }
 
-func (value *Link) Validate(c context.Context) error {
+func (value *Link) Validate(ctx context.Context) error {
 	if value.OperationID == "" && value.OperationRef == "" {
 		return errors.New("missing operationId or operationRef on link")
 	}
 	if value.OperationID != "" && value.OperationRef != "" {
-		return fmt.Errorf("operationId '%s' and operationRef '%s' are mutually exclusive", value.OperationID, value.OperationRef)
+		return fmt.Errorf("operationId %q and operationRef %q are mutually exclusive", value.OperationID, value.OperationRef)
 	}
 	return nil
 }
