@@ -2,10 +2,28 @@ package openapi3
 
 import (
 	"context"
+	"fmt"
 
 	"github.com/getkin/kin-openapi/jsoninfo"
+	"github.com/go-openapi/jsonpointer"
 )
 
+type RequestBodies map[string]*RequestBodyRef
+
+var _ jsonpointer.JSONPointable = (*RequestBodyRef)(nil)
+
+func (r RequestBodies) JSONLookup(token string) (interface{}, error) {
+	ref, ok := r[token]
+	if ok == false {
+		return nil, fmt.Errorf("object has no field %q", token)
+	}
+
+	if ref != nil && ref.Ref != "" {
+		return &Ref{Ref: ref.Ref}, nil
+	}
+	return ref.Value, nil
+}
+
 // RequestBody is specified by OpenAPI/Swagger 3.0 standard.
 type RequestBody struct {
 	ExtensionProps
@@ -79,9 +97,9 @@ func (requestBody *RequestBody) UnmarshalJSON(data []byte) error {
 	return jsoninfo.UnmarshalStrictStruct(data, requestBody)
 }
 
-func (requestBody *RequestBody) Validate(c context.Context) error {
-	if v := requestBody.Content; v != nil {
-		if err := v.Validate(c); err != nil {
+func (value *RequestBody) Validate(ctx context.Context) error {
+	if v := value.Content; v != nil {
+		if err := v.Validate(ctx); err != nil {
 			return err
 		}
 	}
