@@ -389,7 +389,7 @@ var schemaExamples = []schemaExample{
 			UniqueItems: true,
 			Items: (&Schema{
 				Type: "object",
-				Properties: map[string]*SchemaRef{
+				Properties: Schemas{
 					"key1": NewFloat64Schema().NewRef(),
 				},
 			}).NewRef(),
@@ -446,7 +446,7 @@ var schemaExamples = []schemaExample{
 			UniqueItems: true,
 			Items: (&Schema{
 				Type: "object",
-				Properties: map[string]*SchemaRef{
+				Properties: Schemas{
 					"key1": (&Schema{
 						Type:        "array",
 						UniqueItems: true,
@@ -579,7 +579,7 @@ var schemaExamples = []schemaExample{
 				UniqueItems: true,
 				Items: (&Schema{
 					Type: "object",
-					Properties: map[string]*SchemaRef{
+					Properties: Schemas{
 						"key1": NewFloat64Schema().NewRef(),
 					},
 				}).NewRef(),
@@ -678,7 +678,7 @@ var schemaExamples = []schemaExample{
 		Schema: &Schema{
 			Type:     "object",
 			MaxProps: Uint64Ptr(2),
-			Properties: map[string]*SchemaRef{
+			Properties: Schemas{
 				"numberProperty": NewFloat64Schema().NewRef(),
 			},
 		},
@@ -1082,7 +1082,7 @@ func testSchemaMultiError(t *testing.T, example schemaMultiErrorExample) func(*t
 						break
 					}
 				}
-				require.True(t, found, fmt.Sprintf("Missing %s error on %s", scherr.SchemaField, strings.Join(scherr.JSONPointer(), ".")))
+				require.True(t, found, fmt.Sprintf("missing %s error on %s", scherr.SchemaField, strings.Join(scherr.JSONPointer(), ".")))
 			}
 		}
 	}
@@ -1192,3 +1192,40 @@ var schemaMultiErrorExamples = []schemaMultiErrorExample{
 		},
 	},
 }
+
+func TestIssue283(t *testing.T) {
+	const api = `
+openapi: "3.0.1"
+components:
+  schemas:
+    Test:
+      properties:
+        name:
+          type: string
+        ownerName:
+          not:
+            type: boolean
+      type: object
+`
+	data := map[string]interface{}{
+		"name":      "kin-openapi",
+		"ownerName": true,
+	}
+	s, err := NewLoader().LoadFromData([]byte(api))
+	require.NoError(t, err)
+	require.NotNil(t, s)
+	err = s.Components.Schemas["Test"].Value.VisitJSON(data)
+	require.NotNil(t, err)
+	require.NotEqual(t, errSchema, err)
+	require.Contains(t, err.Error(), `Error at "/ownerName": Doesn't match schema "not"`)
+}
+
+func TestValidationFailsOnInvalidPattern(t *testing.T) {
+	schema := Schema{
+		Pattern: "[",
+		Type:    "string",
+	}
+
+	var err = schema.Validate(context.Background())
+	require.Error(t, err)
+}
