@@ -2,7 +2,6 @@ package openapi3filter
 
 import (
 	"fmt"
-	"strings"
 
 	"github.com/getkin/kin-openapi/openapi3"
 )
@@ -16,19 +15,15 @@ type AuthenticationInput struct {
 
 func (input *AuthenticationInput) NewError(err error) error {
 	if err == nil {
-		scopes := input.Scopes
-		if len(scopes) == 0 {
-			err = fmt.Errorf("Security requirement '%s' failed",
-				input.SecuritySchemeName)
+		if len(input.Scopes) == 0 {
+			err = fmt.Errorf("security requirement %q failed", input.SecuritySchemeName)
 		} else {
-			err = fmt.Errorf("Security requirement '%s' (scopes: '%s') failed",
-				input.SecuritySchemeName,
-				strings.Join(input.Scopes, "', '"))
+			err = fmt.Errorf("security requirement %q (scopes: %+v) failed", input.SecuritySchemeName, input.Scopes)
 		}
 	}
 	return &RequestError{
 		Input:  input.RequestValidationInput,
-		Reason: "Authorization failed",
+		Reason: "authorization failed",
 		Err:    err,
 	}
 }
