@@ -11,6 +11,7 @@ import (
 	"testing"
 
 	"github.com/getkin/kin-openapi/openapi3"
+	"github.com/getkin/kin-openapi/routers"
 	"github.com/stretchr/testify/require"
 )
 
@@ -19,7 +20,7 @@ func newPetstoreRequest(t *testing.T, method, path string, body io.Reader) *http
 	pathPrefix := "v2"
 	r, err := http.NewRequest(method, fmt.Sprintf("http://%s/%s%s", host, pathPrefix, path), body)
 	require.NoError(t, err)
-	r.Header.Set("Content-Type", "application/json")
+	r.Header.Set(headerCT, "application/json")
 	r.Header.Set("Authorization", "Bearer magicstring")
 	r.Host = host
 	return r
@@ -27,7 +28,7 @@ func newPetstoreRequest(t *testing.T, method, path string, body io.Reader) *http
 
 type validationFields struct {
 	Handler      http.Handler
-	SwaggerFile  string
+	File         string
 	ErrorEncoder ErrorEncoder
 }
 type validationArgs struct {
@@ -55,7 +56,8 @@ type validationTest struct {
 }
 
 func getValidationTests(t *testing.T) []*validationTest {
-	badHost, _ := http.NewRequest(http.MethodGet, "http://unknown-host.com/v2/pet", nil)
+	badHost, err := http.NewRequest(http.MethodGet, "http://unknown-host.com/v2/pet", nil)
+	require.NoError(t, err)
 	badPath := newPetstoreRequest(t, http.MethodGet, "/watdis", nil)
 	badMethod := newPetstoreRequest(t, http.MethodTrace, "/pet", nil)
 
@@ -63,16 +65,16 @@ func getValidationTests(t *testing.T) []*validationTest {
 	missingBody2 := newPetstoreRequest(t, http.MethodPost, "/pet", bytes.NewBufferString(``))
 
 	noContentType := newPetstoreRequest(t, http.MethodPost, "/pet", bytes.NewBufferString(`{}`))
-	noContentType.Header.Del("Content-Type")
+	noContentType.Header.Del(headerCT)
 
 	noContentTypeNeeded := newPetstoreRequest(t, http.MethodGet, "/pet/findByStatus?status=sold", nil)
-	noContentTypeNeeded.Header.Del("Content-Type")
+	noContentTypeNeeded.Header.Del(headerCT)
 
 	unknownContentType := newPetstoreRequest(t, http.MethodPost, "/pet", bytes.NewBufferString(`{}`))
-	unknownContentType.Header.Set("Content-Type", "application/xml")
+	unknownContentType.Header.Set(headerCT, "application/xml")
 
 	unsupportedContentType := newPetstoreRequest(t, http.MethodPost, "/pet", bytes.NewBufferString(`{}`))
-	unsupportedContentType.Header.Set("Content-Type", "text/plain")
+	unsupportedContentType.Header.Set(headerCT, "text/plain")
 
 	unsupportedHeaderValue := newPetstoreRequest(t, http.MethodPost, "/pet", bytes.NewBufferString(`{}`))
 	unsupportedHeaderValue.Header.Set("x-environment", "watdis")
@@ -87,45 +89,45 @@ func getValidationTests(t *testing.T) []*validationTest {
 			args: validationArgs{
 				r: badHost,
 			},
-			wantErrReason:   "Does not match any server",
-			wantErrResponse: &ValidationError{Status: http.StatusNotFound, Title: "Does not match any server"},
+			wantErrReason:   routers.ErrPathNotFound.Error(),
+			wantErrResponse: &ValidationError{Status: http.StatusNotFound, Title: routers.ErrPathNotFound.Error()},
 		},
 		{
 			name: "error - unknown path",
 			args: validationArgs{
 				r: badPath,
 			},
-			wantErrReason:   "Path was not found",
-			wantErrResponse: &ValidationError{Status: http.StatusNotFound, Title: "Path was not found"},
+			wantErrReason:   routers.ErrPathNotFound.Error(),
+			wantErrResponse: &ValidationError{Status: http.StatusNotFound, Title: routers.ErrPathNotFound.Error()},
 		},
 		{
 			name: "error - unknown method",
 			args: validationArgs{
 				r: badMethod,
 			},
-			wantErrReason: "Path doesn't support the HTTP method",
+			wantErrReason: routers.ErrMethodNotAllowed.Error(),
 			// TODO: By HTTP spec, this should have an Allow header with what is allowed
 			// but kin-openapi doesn't provide us the requested method or path, so impossible to provide details
 			wantErrResponse: &ValidationError{Status: http.StatusMethodNotAllowed,
-				Title: "Path doesn't support the HTTP method"},
+				Title: routers.ErrMethodNotAllowed.Error()},
 		},
 		{
 			name: "error - missing body on POST",
 			args: validationArgs{
 				r: missingBody1,
 			},
-			wantErrBody: "Request body has an error: must have a value",
+			wantErrBody: "request body has an error: " + ErrInvalidRequired.Error(),
 			wantErrResponse: &ValidationError{Status: http.StatusBadRequest,
-				Title: "Request body has an error: must have a value"},
+				Title: "request body has an error: " + ErrInvalidRequired.Error()},
 		},
 		{
 			name: "error - empty body on POST",
 			args: validationArgs{
 				r: missingBody2,
 			},
-			wantErrBody: "Request body has an error: must have a value",
+			wantErrBody: "request body has an error: " + ErrInvalidRequired.Error(),
 			wantErrResponse: &ValidationError{Status: http.StatusBadRequest,
-				Title: "Request body has an error: must have a value"},
+				Title: "request body has an error: " + ErrInvalidRequired.Error()},
 		},
 
 		//
@@ -137,9 +139,9 @@ func getValidationTests(t *testing.T) []*validationTest {
 			args: validationArgs{
 				r: noContentType,
 			},
-			wantErrReason: "header 'Content-Type' has unexpected value: \"\"",
+			wantErrReason: prefixInvalidCT + ` ""`,
 			wantErrResponse: &ValidationError{Status: http.StatusUnsupportedMediaType,
-				Title: "header 'Content-Type' is required"},
+				Title: "header Content-Type is required"},
 		},
 		{
 			name: "error - unknown content-type on POST",
@@ -148,18 +150,18 @@ func getValidationTests(t *testing.T) []*validationTest {
 			},
 			wantErrReason:      "failed to decode request body",
 			wantErrParseKind:   KindUnsupportedFormat,
-			wantErrParseReason: "unsupported content type \"application/xml\"",
+			wantErrParseReason: prefixUnsupportedCT + ` "application/xml"`,
 			wantErrResponse: &ValidationError{Status: http.StatusUnsupportedMediaType,
-				Title: "unsupported content type \"application/xml\""},
+				Title: prefixUnsupportedCT + ` "application/xml"`},
 		},
 		{
 			name: "error - unsupported content-type on POST",
 			args: validationArgs{
 				r: unsupportedContentType,
 			},
-			wantErrReason: "header 'Content-Type' has unexpected value: \"text/plain\"",
+			wantErrReason: prefixInvalidCT + ` "text/plain"`,
 			wantErrResponse: &ValidationError{Status: http.StatusUnsupportedMediaType,
-				Title: "unsupported content type \"text/plain\""},
+				Title: prefixUnsupportedCT + ` "text/plain"`},
 		},
 		{
 			name: "success - no content-type header required on GET",
@@ -179,9 +181,9 @@ func getValidationTests(t *testing.T) []*validationTest {
 			},
 			wantErrParam:   "status",
 			wantErrParamIn: "query",
-			wantErrReason:  "must have a value",
+			wantErrBody:    `parameter "status" in query has an error: value is required but missing`,
 			wantErrResponse: &ValidationError{Status: http.StatusBadRequest,
-				Title: "Parameter 'status' in query is required"},
+				Title: `parameter "status" in query is required`},
 		},
 		{
 			name: "error - wrong query string parameter type",
@@ -192,11 +194,11 @@ func getValidationTests(t *testing.T) []*validationTest {
 			wantErrParamIn: "query",
 			// This is a nested ParseError. The outer error is a KindOther with no details.
 			// So we'd need to look at the inner one which is a KindInvalidFormat. So just check the error body.
-			wantErrBody: "Parameter 'ids' in query has an error: path 1: value notAnInt: an invalid integer: " +
+			wantErrBody: `parameter "ids" in query has an error: path 1: value notAnInt: an invalid integer: ` +
 				"strconv.ParseFloat: parsing \"notAnInt\": invalid syntax",
 			// TODO: Should we treat query params of the wrong type like a 404 instead of a 400?
 			wantErrResponse: &ValidationError{Status: http.StatusBadRequest,
-				Title: "Parameter 'ids' in query is invalid: notAnInt is an invalid integer"},
+				Title: `parameter "ids" in query is invalid: notAnInt is an invalid integer`},
 		},
 		{
 			name: "success - ignores unknown query string parameter",
@@ -223,12 +225,12 @@ func getValidationTests(t *testing.T) []*validationTest {
 			},
 			wantErrParam:        "status",
 			wantErrParamIn:      "query",
-			wantErrSchemaReason: "JSON value is not one of the allowed values",
+			wantErrSchemaReason: "value is not one of the allowed values",
 			wantErrSchemaPath:   "/0",
 			wantErrSchemaValue:  "available,sold",
 			wantErrResponse: &ValidationError{Status: http.StatusBadRequest,
-				Title: "JSON value is not one of the allowed values",
-				Detail: "Value 'available,sold' at /0 must be one of: available, pending, sold; " +
+				Title: "value is not one of the allowed values",
+				Detail: "value available,sold at /0 must be one of: available, pending, sold; " +
 					// TODO: do we really want to use this heuristic to guess
 					//  that they're using the wrong serialization?
 					"perhaps you intended '?status=available&status=sold'",
@@ -241,12 +243,12 @@ func getValidationTests(t *testing.T) []*validationTest {
 			},
 			wantErrParam:        "status",
 			wantErrParamIn:      "query",
-			wantErrSchemaReason: "JSON value is not one of the allowed values",
+			wantErrSchemaReason: "value is not one of the allowed values",
 			wantErrSchemaPath:   "/1",
 			wantErrSchemaValue:  "watdis",
 			wantErrResponse: &ValidationError{Status: http.StatusBadRequest,
-				Title:  "JSON value is not one of the allowed values",
-				Detail: "Value 'watdis' at /1 must be one of: available, pending, sold",
+				Title:  "value is not one of the allowed values",
+				Detail: "value watdis at /1 must be one of: available, pending, sold",
 				Source: &ValidationErrorSource{Parameter: "status"}},
 		},
 		{
@@ -257,12 +259,12 @@ func getValidationTests(t *testing.T) []*validationTest {
 			},
 			wantErrParam:        "kind",
 			wantErrParamIn:      "query",
-			wantErrSchemaReason: "JSON value is not one of the allowed values",
+			wantErrSchemaReason: "value is not one of the allowed values",
 			wantErrSchemaPath:   "/1",
 			wantErrSchemaValue:  "fish,with,commas",
 			wantErrResponse: &ValidationError{Status: http.StatusBadRequest,
-				Title:  "JSON value is not one of the allowed values",
-				Detail: "Value 'fish,with,commas' at /1 must be one of: dog, cat, turtle, bird,with,commas",
+				Title:  "value is not one of the allowed values",
+				Detail: "value fish,with,commas at /1 must be one of: dog, cat, turtle, bird,with,commas",
 				// No 'perhaps you intended' because its the right serialization format
 				Source: &ValidationErrorSource{Parameter: "kind"}},
 		},
@@ -283,12 +285,12 @@ func getValidationTests(t *testing.T) []*validationTest {
 			},
 			wantErrParam:        "x-environment",
 			wantErrParamIn:      "header",
-			wantErrSchemaReason: "JSON value is not one of the allowed values",
+			wantErrSchemaReason: "value is not one of the allowed values",
 			wantErrSchemaPath:   "/",
 			wantErrSchemaValue:  "watdis",
 			wantErrResponse: &ValidationError{Status: http.StatusBadRequest,
-				Title:  "JSON value is not one of the allowed values",
-				Detail: "Value 'watdis' at / must be one of: demo, prod",
+				Title:  "value is not one of the allowed values",
+				Detail: "value watdis at / must be one of: demo, prod",
 				Source: &ValidationErrorSource{Parameter: "x-environment"}},
 		},
 
@@ -302,12 +304,12 @@ func getValidationTests(t *testing.T) []*validationTest {
 				r: newPetstoreRequest(t, http.MethodPost, "/pet", bytes.NewBufferString(`{"status":"watdis"}`)),
 			},
 			wantErrReason:       "doesn't match the schema",
-			wantErrSchemaReason: "JSON value is not one of the allowed values",
+			wantErrSchemaReason: "value is not one of the allowed values",
 			wantErrSchemaValue:  "watdis",
 			wantErrSchemaPath:   "/status",
 			wantErrResponse: &ValidationError{Status: http.StatusUnprocessableEntity,
-				Title:  "JSON value is not one of the allowed values",
-				Detail: "Value 'watdis' at /status must be one of: available, pending, sold",
+				Title:  "value is not one of the allowed values",
+				Detail: "value watdis at /status must be one of: available, pending, sold",
 				Source: &ValidationErrorSource{Pointer: "/status"}},
 		},
 		{
@@ -316,11 +318,11 @@ func getValidationTests(t *testing.T) []*validationTest {
 				r: newPetstoreRequest(t, http.MethodPost, "/pet", bytes.NewBufferString(`{"name":"Bahama"}`)),
 			},
 			wantErrReason:       "doesn't match the schema",
-			wantErrSchemaReason: "Property 'photoUrls' is missing",
+			wantErrSchemaReason: `property "photoUrls" is missing`,
 			wantErrSchemaValue:  map[string]string{"name": "Bahama"},
 			wantErrSchemaPath:   "/photoUrls",
 			wantErrResponse: &ValidationError{Status: http.StatusUnprocessableEntity,
-				Title:  "Property 'photoUrls' is missing",
+				Title:  `property "photoUrls" is missing`,
 				Source: &ValidationErrorSource{Pointer: "/photoUrls"}},
 		},
 		{
@@ -330,11 +332,11 @@ func getValidationTests(t *testing.T) []*validationTest {
 					bytes.NewBufferString(`{"name":"Bahama","photoUrls":[],"category":{}}`)),
 			},
 			wantErrReason:       "doesn't match the schema",
-			wantErrSchemaReason: "Property 'name' is missing",
+			wantErrSchemaReason: `property "name" is missing`,
 			wantErrSchemaValue:  map[string]string{},
 			wantErrSchemaPath:   "/category/name",
 			wantErrResponse: &ValidationError{Status: http.StatusUnprocessableEntity,
-				Title:  "Property 'name' is missing",
+				Title:  `property "name" is missing`,
 				Source: &ValidationErrorSource{Pointer: "/category/name"}},
 		},
 		{
@@ -344,11 +346,11 @@ func getValidationTests(t *testing.T) []*validationTest {
 					bytes.NewBufferString(`{"name":"Bahama","photoUrls":[],"category":{"tags": [{}]}}`)),
 			},
 			wantErrReason:       "doesn't match the schema",
-			wantErrSchemaReason: "Property 'name' is missing",
+			wantErrSchemaReason: `property "name" is missing`,
 			wantErrSchemaValue:  map[string]string{},
 			wantErrSchemaPath:   "/category/tags/0/name",
 			wantErrResponse: &ValidationError{Status: http.StatusUnprocessableEntity,
-				Title:  "Property 'name' is missing",
+				Title:  `property "name" is missing`,
 				Source: &ValidationErrorSource{Pointer: "/category/tags/0/name"}},
 		},
 		{
@@ -384,11 +386,11 @@ func getValidationTests(t *testing.T) []*validationTest {
 			wantErrReason:             "doesn't match the schema",
 			wantErrSchemaPath:         "/",
 			wantErrSchemaValue:        map[string]string{"name": "Bahama"},
-			wantErrSchemaOriginReason: "Property 'photoUrls' is missing",
+			wantErrSchemaOriginReason: `property "photoUrls" is missing`,
 			wantErrSchemaOriginValue:  map[string]string{"name": "Bahama"},
 			wantErrSchemaOriginPath:   "/photoUrls",
 			wantErrResponse: &ValidationError{Status: http.StatusUnprocessableEntity,
-				Title:  "Property 'photoUrls' is missing",
+				Title:  `property "photoUrls" is missing`,
 				Source: &ValidationErrorSource{Pointer: "/photoUrls"}},
 		},
 		{
@@ -423,9 +425,9 @@ func getValidationTests(t *testing.T) []*validationTest {
 			},
 			wantErrParam:   "petId",
 			wantErrParamIn: "path",
-			wantErrReason:  "must have a value",
+			wantErrBody:    `parameter "petId" in path has an error: value is required but missing`,
 			wantErrResponse: &ValidationError{Status: http.StatusBadRequest,
-				Title: "Parameter 'petId' in path is required"},
+				Title: `parameter "petId" in path is required`},
 		},
 		{
 			name: "error - wrong path param type",
@@ -438,7 +440,7 @@ func getValidationTests(t *testing.T) []*validationTest {
 			wantErrParseValue:  "NotAnInt",
 			wantErrParseReason: "an invalid integer",
 			wantErrResponse: &ValidationError{Status: http.StatusNotFound,
-				Title: "Resource not found with 'petId' value: NotAnInt"},
+				Title: `resource not found with "petId" value: NotAnInt`},
 		},
 		{
 			name: "success - normal case, with path params",
@@ -466,13 +468,13 @@ func TestValidationHandler_validateRequest(t *testing.T) {
 					req.Equal(tt.wantErrBody, err.Error())
 				}
 
-				if e, ok := err.(*RouteError); ok {
-					req.Equal(tt.wantErrReason, e.Reason)
+				if e, ok := err.(*routers.RouteError); ok {
+					req.Equal(tt.wantErrReason, e.Error())
 					return
 				}
 
 				e, ok := err.(*RequestError)
-				req.True(ok, "error = %v, not a RequestError -- %#v", err, err)
+				req.True(ok, "not a RequestError: %T -- %#v", err, err)
 
 				req.Equal(tt.wantErrReason, e.Reason)
 
@@ -542,12 +544,12 @@ func TestValidationErrorEncoder(t *testing.T) {
 }
 
 func buildValidationHandler(tt *validationTest) (*ValidationHandler, error) {
-	if tt.fields.SwaggerFile == "" {
-		tt.fields.SwaggerFile = "fixtures/petstore.json"
+	if tt.fields.File == "" {
+		tt.fields.File = "fixtures/petstore.json"
 	}
 	h := &ValidationHandler{
 		Handler:      tt.fields.Handler,
-		SwaggerFile:  tt.fields.SwaggerFile,
+		File:         tt.fields.File,
 		ErrorEncoder: tt.fields.ErrorEncoder,
 	}
 	tt.wantErr = tt.wantErr ||
@@ -587,7 +589,7 @@ func runTest_ServeHTTP(t *testing.T, handler http.Handler, encoder ErrorEncoder,
 	h := &ValidationHandler{
 		Handler:      handler,
 		ErrorEncoder: encoder,
-		SwaggerFile:  "fixtures/petstore.json",
+		File:         "fixtures/petstore.json",
 	}
 	err := h.Load()
 	require.NoError(t, err)
@@ -599,7 +601,7 @@ func runTest_ServeHTTP(t *testing.T, handler http.Handler, encoder ErrorEncoder,
 func runTest_Middleware(t *testing.T, handler http.Handler, encoder ErrorEncoder, req *http.Request) *http.Response {
 	h := &ValidationHandler{
 		ErrorEncoder: encoder,
-		SwaggerFile:  "fixtures/petstore.json",
+		File:         "fixtures/petstore.json",
 	}
 	err := h.Load()
 	require.NoError(t, err)
